@@ -20,9 +20,9 @@
 
 #include <QPushButton>
 
-#include <KLocalizedString>
-#include <KConfigSkeleton>
 #include <KConfigGroup>
+#include <KConfigSkeleton>
+#include <KLocalizedString>
 
 #include "preftutor.h"
 
@@ -33,14 +33,14 @@ KWQTutorPrefs::KWQTutorPrefs(QWidget *parent, const QString &name, KConfigSkelet
   m_config = config;
 
   m_prefTutor = new PrefTutor(0);
-  addPage(m_prefTutor, i18nc("@title:group tutor settings", "Tutor"), "kwordquiz", i18nc("@title:group tutor settings", "Tutor Settings"), true);
+  addPage(m_prefTutor, i18nc("@title:group tutor settings", "Tutor"), QStringLiteral("kwordquiz"), i18nc("@title:group tutor settings", "Tutor Settings"), true);
 
   m_shortcutsWidget = new KShortcutsEditor( actionCollection, 0, KShortcutsEditor::GlobalAction );
-  addPage(m_shortcutsWidget, i18nc("Shortcuts Config", "Shortcuts"), "configure-shortcuts", i18n("Shortcuts Settings"));
+  addPage(m_shortcutsWidget, i18nc("Shortcuts Config", "Shortcuts"), QStringLiteral("configure-shortcuts"), i18n("Shortcuts Settings"));
 
-  connect(m_shortcutsWidget, SIGNAL(keyChange()), this, SLOT(slotEnableApplyButton()));
+  connect(m_shortcutsWidget, &KShortcutsEditor::keyChange, this, &KWQTutorPrefs::slotEnableApplyButton);
 
-  setHelp(QString(), "kwordquiz");
+  setHelp(QString(), QStringLiteral("kwordquiz"));
 }
 
 bool KWQTutorPrefs::hasChanged()
